let request = require('./requestLib');

exports.getFilesList = async function (req, res, tokenHandler) {
    await getFiles(req, res, tokenHandler, true);
};

exports.getFoldersList = async function (req, res, tokenHandler) {
    await getFolders(req, res, tokenHandler, true);
};

exports.download = async function (req, res, tokenHandler) {
    await downloadFile(req, res, tokenHandler, true);
};

let getFiles = async function (req, res, tokenHandler, canRefreshToken) {
    try {
        let path = "/";

        if (req.body.link && req.body.link !== "") {
            path += req.body.link;
        } else {
            path += req.body.folder;
        }
        let result = await request.get(req, {headers: {'content-type': 'application/json', 'Authorization': 'Bearer ' + tokenHandler.accessToken()}, url: process.env.ENDPOINT_URL + "/datadelivery" + path}, true);
        if (result && result.statusCode) {
            if (result.statusCode === 200) {
                let body = JSON.parse(result.body);
                res.send(body);
            } else if (result.statusCode === 401 && canRefreshToken) {
                await tokenHandler.getNewAccessTokenFromRefreshToken(req);
                await getFiles(req, res, tokenHandler, false);
            } else {
                let message = "An error occured";
                let body = JSON.parse(result.body);
                if (body && body.message) {
                    message = body.message;
                }
                res.status(400).send('{"message": "' + message + '"}');
            }
        }
    } catch (error) {
        res.status(400).send('{"message": "' + error + '"}');
    }

};

let downloadFile = async function (req, res, tokenHandler, canRefreshToken) {
    try {
        console.log(process.env.ENDPOINT_URL + "/datadelivery/" + req.query.path);
        let result = await request.get(req,{
            headers: {'content-type': 'application/json', 'Authorization': 'Bearer ' + tokenHandler.accessToken()},
            url: process.env.ENDPOINT_URL + "/datadelivery/" + req.query.path
        });
        if (result && result.statusCode) {
            if (result.statusCode === 200) {
                res.setHeader('Content-type', "application/octet-stream");
                res.setHeader('Content-disposition', 'attachment; filename=' + req.query.filename);
                res.send(result.body);
            } else if (result.statusCode === 401 && canRefreshToken) {
                await tokenHandler.getNewAccessTokenFromRefreshToken(req);
                await downloadFile(req, res, tokenHandler, false);
            } else {
                let message = "An error occured";
                let body = JSON.parse(result.body);
                if (body && body.message) {
                    message = body.message;
                }
                res.redirect('/callback?statusCode=' + response.statusCode + '&error=' + message);
            }
        }
    } catch (error) {
        res.status(400).send('{"message": "' + error + '"}');
    }

};

let getFolders = async function (req, res, tokenHandler, canRefreshToken) {

    console.log(process.env.ENDPOINT_URL + "/folders");
    try {
        let result = await request.get(req,{headers: {'content-type': 'application/json', 'Authorization': 'Bearer ' + tokenHandler.accessToken()}, url: process.env.ENDPOINT_URL + "/folders"}, true)
        if (result.statusCode === 200) {
            console.log(JSON.stringify(result));
            res.send(result.body);
        } else if (result.statusCode === 401 && canRefreshToken) {
            await tokenHandler.getNewAccessTokenFromRefreshToken(req);
            await getFolders(req, res, tokenHandler, false);
        } else {
            let message = "An error occured";
            let body = JSON.parse(result.body);
            if (body && body.message) {
                message = body.message;
            }
            res.status(400).send('{"message": "' + message + '"}');
        }
    } catch (error) {
        res.status(400).send('{"message": "' + error + '"}');
    }


};
